Crate clingwrap

Crate clingwrap 

Utility types and functions for implementing command line applications in Rust.

Modules

config
Configuration file handling.
indent
Format a string for nicer output.
runner
Run a Command, handling errors in a way that is convenient for the caller to handle. Specifically, the error type returned by this module distinguishes between “program doesn’t exist” and “no permission to execute program” and “program ran, but failed”. See CommandError for all possible errors.
ssh
Create a Command to run things on a remote host over SSH using local ssh command.
tildepathbuf
A type to represent filenames that need tilde expansion.