Utility types and functions for implementing command line applications in Rust.
Modules
- config
- Configuration file handling.
- indent
- Format a string for nicer output.
- runner
- Run a
Command, handling errors in a way that is convenient for the caller to handle. Specifically, the error type returned by this module distinguishes between “program doesn’t exist” and “no permission to execute program” and “program ran, but failed”. SeeCommandErrorfor all possible errors. - ssh
- Create a
Commandto run things on a remote host over SSH using localsshcommand. - tildepathbuf
- A type to represent filenames that need tilde expansion.